@@ -54,27 +54,22 @@ class Population:
             del self.birds[-1]
         self.birds = next_gen
 
-    def mutate(self, mutate_r8, radius_ratio, immune=0, reinit=0.01):
+    def mutate(self, mutate_r8, radius_ratio, reinit=0.01, immune=1):
         police = []
         for i in range(immune):
-            police.append(copy.deepcopy(sorted(self.birds, key=lambda x: x.fitness)[-(i + 1)]))
+            police.append(sorted(self.birds, key=lambda x: x.fitness)[-i])
         for bird in self.birds:
-            if np.random.uniform() < .96:
+            if np.random.uniform() < .98:
                 for matrix in range(len(bird.matrices)):
                     for row in range(len(bird.matrices[matrix])):
                         for col in range(len(bird.matrices[matrix][0])):
                             if np.random.uniform() < mutate_r8:
-                                bird.matrices[matrix][row][col] += np.random.normal(0, 1/np.sqrt(len(bird.matrices[matrix][0])) * radius_ratio, 1)[0]
-                                if np.random.uniform() < reinit:
-                                    bird.matrices[matrix][row][col] = np.random.normal(0, 1/np.sqrt(len(bird.matrices[matrix][0])), 1)[0]
+                                bird.matrices[matrix][row][col] += np.random.normal(0, radius_ratio / np.sqrt(len(bird.matrices[matrix][0])), 1)[0]
         random.shuffle(self.birds)
         for i in range(immune):
             del self.birds[i]
             self.birds.append(police[i])
         random.shuffle(self.birds)
-        
-
-
 
 class Bird:
     def __init__(self, hl_count, layer_node_counts, mat = []):
